@@ -137,6 +137,8 @@ MainView* interface_main_view_new(AppData *data)
 {
   m_button_pressed=FALSE;
   p_button_pressed=FALSE;
+//fremantle
+  pm_button_for_toggle_fullscreen=FALSE;
 
     // Zero memory with g_new0
     MainView* result = g_new0(MainView, 1);
@@ -198,7 +200,8 @@ MainView* interface_main_view_new(AppData *data)
 	!gconf_client_get_bool(result->gc_client,
 			       MAEMO_VNCVIEWER_GCONF_FULLSCREEN_TOOLBAR, 0);
 //fremantle force FullscreenToolbar
-    result->bShowFullscreenToolbar = TRUE;
+// removed again
+//    result->bShowFullscreenToolbar = TRUE;
 
     result->bShowScrollbars =
       !gconf_client_get_bool(result->gc_client,
@@ -365,7 +368,7 @@ void options_button_clicked(GtkButton *button,
   GtkToggleButton *default_radio, *eight_bit_radio, *sixteen_bit_radio;
   GtkToggleButton *toggle = 0;
 
-  dialog = gtk_dialog_new_with_buttons("VNC Viewer: Options",
+  dialog = gtk_dialog_new_with_buttons(_("VNC Viewer: Options"),
 				       GTK_WINDOW(parent_dialog),
 				       (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
 				       GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
@@ -389,7 +392,7 @@ void options_button_clicked(GtkButton *button,
   pOpts = (options_settings *) g_object_get_data(G_OBJECT(parent_dialog),
 						 "options");
 
-  shared_button = gtk_check_button_new_with_mnemonic("_Shared connection (do not disconnect other viewers)");
+  shared_button = gtk_check_button_new_with_mnemonic(_("_Shared connection (do not disconnect other viewers)"));
   //gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), shared_button);
   gtk_box_pack_start(GTK_BOX(main_vbox), shared_button, TRUE, TRUE, 5);
   //gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), shared_button,
@@ -397,7 +400,7 @@ void options_button_clicked(GtkButton *button,
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(shared_button),
 			       pOpts->m_bShared);
 
-  frame = gtk_frame_new("Display depth");
+  frame = gtk_frame_new(_("Display depth"));
   gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_ETCHED_IN);
   //gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), frame);
   gtk_box_pack_start(GTK_BOX(main_vbox), frame, TRUE, TRUE, 5);
@@ -409,11 +412,11 @@ void options_button_clicked(GtkButton *button,
   gtk_container_add(GTK_CONTAINER(frame), vbox);
   //gtk_container_set_border_width(GTK_CONTAINER(vbox), 1);
 
-  default_radio = GTK_TOGGLE_BUTTON(gtk_radio_button_new_with_mnemonic(0, "Server _Default"));
+  default_radio = GTK_TOGGLE_BUTTON(gtk_radio_button_new_with_mnemonic(0, _("Server _Default")));
   eight_bit_radio =
-    GTK_TOGGLE_BUTTON(gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(default_radio), "_8-bit"));
+    GTK_TOGGLE_BUTTON(gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(default_radio), _("_8-bit")));
   sixteen_bit_radio =
-    GTK_TOGGLE_BUTTON(gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(eight_bit_radio), "_16-bit"));
+    GTK_TOGGLE_BUTTON(gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(eight_bit_radio), _("_16-bit")));
 
   gtk_container_add(GTK_CONTAINER(vbox), GTK_WIDGET(default_radio));
   gtk_container_add(GTK_CONTAINER(vbox), GTK_WIDGET(eight_bit_radio));
@@ -440,7 +443,7 @@ void options_button_clicked(GtkButton *button,
   gtk_toggle_button_set_active(toggle, TRUE);
 
   // encoding
-  GtkWidget *encoding_frame = gtk_frame_new("Preferred encoding");
+  GtkWidget *encoding_frame = gtk_frame_new(_("Preferred encoding"));
   gtk_frame_set_shadow_type(GTK_FRAME(encoding_frame), GTK_SHADOW_ETCHED_IN);
   gtk_box_pack_start(GTK_BOX(main_vbox), encoding_frame, TRUE, TRUE, 5);
   //gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), encoding_frame,
@@ -450,11 +453,11 @@ void options_button_clicked(GtkButton *button,
   gtk_container_add(GTK_CONTAINER(encoding_frame), encoding_vbox);
 
   GtkToggleButton *auto_encoding_radio =
-    GTK_TOGGLE_BUTTON(gtk_radio_button_new_with_mnemonic(0, "Automatically _select"));
+    GTK_TOGGLE_BUTTON(gtk_radio_button_new_with_mnemonic(0, _("Automatically _select")));
   GtkToggleButton *raw_encoding_radio =
-    GTK_TOGGLE_BUTTON(gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(auto_encoding_radio), "Ra_w"));
+    GTK_TOGGLE_BUTTON(gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(auto_encoding_radio), _("Ra_w")));
   GtkToggleButton *hextile_encoding_radio =
-    GTK_TOGGLE_BUTTON(gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(raw_encoding_radio), "_Hextile"));
+    GTK_TOGGLE_BUTTON(gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(raw_encoding_radio), _("_Hextile")));
 
   gtk_container_add(GTK_CONTAINER(encoding_vbox),
 		    GTK_WIDGET(auto_encoding_radio));
@@ -485,7 +488,7 @@ void options_button_clicked(GtkButton *button,
 
 
   // rotation
-  GtkWidget *rotation_frame = gtk_frame_new("Rotation type");
+  GtkWidget *rotation_frame = gtk_frame_new(_("Rotation type"));
   gtk_frame_set_shadow_type(GTK_FRAME(rotation_frame), GTK_SHADOW_ETCHED_IN);
   gtk_box_pack_start(GTK_BOX(main_vbox), rotation_frame, TRUE, TRUE, 5);
   //gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), rotation_frame,
@@ -495,11 +498,11 @@ void options_button_clicked(GtkButton *button,
   gtk_container_add(GTK_CONTAINER(rotation_frame), rotation_vbox);
 
   GtkToggleButton *auto_rotate_radio =
-    GTK_TOGGLE_BUTTON(gtk_radio_button_new_with_mnemonic(0, "_Automatically rotate"));
+    GTK_TOGGLE_BUTTON(gtk_radio_button_new_with_mnemonic(0, _("_Automatically rotate")));
   GtkToggleButton *always_rotate_radio =
-    GTK_TOGGLE_BUTTON(gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(auto_rotate_radio), "Always _rotate"));
+    GTK_TOGGLE_BUTTON(gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(auto_rotate_radio), _("Always _rotate")));
   GtkToggleButton *never_rotate_radio =
-    GTK_TOGGLE_BUTTON(gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(always_rotate_radio), "_Never rotate"));
+    GTK_TOGGLE_BUTTON(gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(always_rotate_radio), _("_Never rotate")));
 
   gtk_container_add(GTK_CONTAINER(rotation_vbox),
 		    GTK_WIDGET(auto_rotate_radio));
@@ -621,11 +624,11 @@ static void vnc_connection_died(VncViewer *vnc, gpointer data) {
   GtkWidget *msgDialog;
 
   if (arg_lockdown)
-    msgDialog = hildon_note_new_information(GTK_WINDOW(mainview->data->main_view), "Connection to server lost.  Contact the administrator or click OK to attempt to connect again.");
+    msgDialog = hildon_note_new_information(GTK_WINDOW(mainview->data->main_view), _("Connection to server lost.  Contact the administrator or click OK to attempt to connect again."));
   else
     msgDialog =
       hildon_note_new_information(GTK_WINDOW(mainview->data->main_view),
-				    "Connection to server lost");
+				    _("Connection to server lost"));
   gtk_dialog_run(GTK_DIALOG(msgDialog));
   gtk_widget_destroy(msgDialog);
 
@@ -668,7 +671,7 @@ static gboolean make_connection(const gchar *display, gboolean shared,
 
   // Display an information, as connecting may take long, if the wlan is not yet connected
   GtkWidget * banner =hildon_banner_show_animation(GTK_WIDGET(mainview->data->main_view),
-				 "Connecting...","Connecting...");
+				 _("Connecting..."),_("Connecting..."));
   // Wait a while for the xwindows system having handled the banner window
   int tmpi=0;
   while (tmpi++<800)
@@ -683,14 +686,14 @@ static gboolean make_connection(const gchar *display, gboolean shared,
   {
     if (arg_lockdown)
     {
-      msgDialog = hildon_note_new_information(GTK_WINDOW(mainview->data->main_view), "Unable to connect to server.  Contact the administrator or click OK to attempt to connect again.");
+      msgDialog = hildon_note_new_information(GTK_WINDOW(mainview->data->main_view), _("Unable to connect to server.  Contact the administrator or click OK to attempt to connect again."));
       GtkWidget *adminButton = gtk_dialog_add_button(GTK_DIALOG(msgDialog),
 						     GTK_STOCK_PREFERENCES, 1);
-      gtk_button_set_label(GTK_BUTTON(adminButton), "Admin...");
+      gtk_button_set_label(GTK_BUTTON(adminButton), _("Admin..."));
     }
     else
       msgDialog = hildon_note_new_information(GTK_WINDOW(mainview->data->main_view),
-					      "Could not connect to server");
+					      _("Could not connect to server"));
     gint nResponse = gtk_dialog_run(GTK_DIALOG(msgDialog));
     gtk_widget_destroy(msgDialog);
 
@@ -721,7 +724,7 @@ static gboolean make_connection(const gchar *display, gboolean shared,
 	    {
 	      msgDialog =
 		hildon_note_new_information(GTK_WINDOW(mainview->data->main_view),
-					    "Password incorrect");
+					    _("Password incorrect"));
 	      gtk_dialog_run(GTK_DIALOG(msgDialog));
 	      gtk_widget_destroy(msgDialog);
 	    }
@@ -744,7 +747,7 @@ static gboolean make_connection(const gchar *display, gboolean shared,
   {
   case rfbConnFailed:
     tmp = getFailReason(fd);
-    msg = g_strconcat("Connection failed: ", tmp, NULL);
+    msg = g_strconcat(_("Connection failed: "), tmp, NULL);
     g_free(tmp);
 
     msgDialog = hildon_note_new_information(GTK_WINDOW(mainview->data->main_view),
@@ -765,7 +768,7 @@ static gboolean make_connection(const gchar *display, gboolean shared,
       ret = performAuth(fd, arg_password ? arg_password : "");
     else
     {
-      interface_vnc_passwd(mainview, TRUE, "VncAuth", 0, &msg);
+      interface_vnc_passwd(mainview, TRUE, _("VncAuth"), 0, &msg);
       if (!msg)
       {
 	close(fd);
@@ -784,7 +787,7 @@ static gboolean make_connection(const gchar *display, gboolean shared,
     case rfbVncAuthFailed:
       msgDialog =
 	hildon_note_new_information(GTK_WINDOW(mainview->data->main_view),
-				    "Authentication to VNC server failed");
+				    _("Authentication to VNC server failed"));
       gtk_dialog_run(GTK_DIALOG(msgDialog));
       gtk_widget_destroy(msgDialog);
 
@@ -795,7 +798,7 @@ static gboolean make_connection(const gchar *display, gboolean shared,
     case rfbVncAuthTooMany:
       msgDialog =
 	hildon_note_new_information(GTK_WINDOW(mainview->data->main_view),
-				    "Too many authentication failures occurred");
+				    _("Too many authentication failures occurred"));
       gtk_dialog_run(GTK_DIALOG(msgDialog));
       gtk_widget_destroy(msgDialog);
 
@@ -808,7 +811,7 @@ static gboolean make_connection(const gchar *display, gboolean shared,
 
   default:
     msgDialog = hildon_note_new_information(GTK_WINDOW(mainview->data->main_view),
-					    "Unknown error");
+					    _("Unknown error"));
     gtk_dialog_run(GTK_DIALOG(msgDialog));
     gtk_widget_destroy(msgDialog);
 
@@ -935,7 +938,7 @@ static void callback_connect(GtkBin *action, gpointer data)
   GtkComboBox *host_entry_combo;
   GtkEntry *host_entry;
 
-  dialog = gtk_dialog_new_with_buttons("VNC Viewer: Connection Details",
+  dialog = gtk_dialog_new_with_buttons(_("VNC Viewer: Connection Details"),
 				       GTK_WINDOW(mainview->data->main_view),
 				       (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
 				       0);
@@ -948,7 +951,7 @@ static void callback_connect(GtkBin *action, gpointer data)
   // struct to be shared between the two dialogs
   g_object_set_data(G_OBJECT(dialog), "options", &opts);
 
-  options_button = gtk_button_new_with_mnemonic("O_ptions...");
+  options_button = gtk_button_new_with_mnemonic(_("O_ptions..."));
   gtk_button_set_relief(GTK_BUTTON(options_button), GTK_RELIEF_HALF);
   g_signal_connect(G_OBJECT(options_button), "clicked",
 		   G_CALLBACK(options_button_clicked), dialog);
@@ -968,7 +971,7 @@ static void callback_connect(GtkBin *action, gpointer data)
   gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), hbox, TRUE, TRUE, 10);
   //gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), hbox);
 
-  host_label = gtk_label_new("VNC server:");
+  host_label = gtk_label_new(_("VNC server:"));
   host_entry_combo = GTK_COMBO_BOX(gtk_combo_box_entry_new_text());
   host_entry = GTK_ENTRY(GTK_BIN(host_entry_combo)->child);
   g_object_set(G_OBJECT(host_entry), "hildon-input-mode",
@@ -1195,7 +1198,7 @@ void callback_mButton(GtkCheckMenuItem *checkmenuitem, gpointer data)
     mainview->mButton.state=PM_Mmouse;  
   if (gtk_check_menu_item_get_active(mainview->mButton.item_Dclick))
     mainview->mButton.state=PM_Dclick;  
-  g_message("state : %d",mainview->mButton.state);
+  g_message(_("state : %d"),mainview->mButton.state);
 }
 
 void callback_normal_toggled(GtkCheckMenuItem *checkmenuitem, gpointer data)
@@ -1219,7 +1222,8 @@ static void callback_fullscreen_toggled(GtkCheckMenuItem *checkmenuitem, gpointe
 
   mainview->bShowFullscreenToolbar = !mainview->bShowFullscreenToolbar;
 //fremantle force Fullscreen Toolbar
-  mainview->bShowFullscreenToolbar = TRUE;
+//removed again
+//  mainview->bShowFullscreenToolbar = TRUE;
 
   if (mainview->fullscreen)
   {
@@ -1257,19 +1261,19 @@ static void callback_show_scrollbars_toggled(GtkCheckMenuItem *checkmenuitem,
 void callback_about(GtkBin *action, gpointer data)
 {
   MainView *mainview = (MainView *) data;
-  const gchar *authors[3] = { "Aaron Levinson <alevinsn@aracnet.com>",
-			      "Detlef Schmicker <d.schmicker@physik.de>", 0 };
+  const gchar *authors[3] = { _("Aaron Levinson <alevinsn@aracnet.com>"),
+			      _("Detlef Schmicker <dschmicker@physik.de>"), 0 };
   //const gchar *documenters[] = { 0 };
   gtk_show_about_dialog(GTK_WINDOW(mainview->data->main_view),
-			"name",_("VNC Viewer"),
-			"version", VERSION,
-			"copyright", "Copyright(C) 2006-2007 Aaron Levinson, Detlef Schmicker",
+			_("name"),_("VNC Viewer"),
+			_("version"), VERSION,
+			_("copyright"), _("Copyright(C) 2006-2007 Aaron Levinson, Detlef Schmicker"),
 			//"comments", _("A VNC viewer for maemo"),
-			"authors", authors,
+			_("authors"), authors,
 			//"documenters", documenters,
 			//"translator-credits", 0,
-			"website", "http://vncviewer.garage.maemo.org/",
-			"website-label", _("Home page"),
+			_("website"), "http://vncviewer.garage.maemo.org/",
+			_("website-label"), _("Home page"),
 			"logo-icon-name", "vncviewer",
 			0);
 }
@@ -1393,14 +1397,16 @@ gboolean callback_keypress(GtkWidget *widget, GdkEventKey *event,
   switch (event->keyval)
   {
   case GDK_F7:
+    if (!p_button_pressed)
+    	pm_button_for_toggle_fullscreen=TRUE;
     p_button_pressed=TRUE;
-    if (m_button_pressed) 
-	    callback_fullscreen(0, mainview);
+    g_message(_("p button press"));
     return TRUE;
   case GDK_F8:
+    if (!m_button_pressed)
+    	pm_button_for_toggle_fullscreen=TRUE;
     m_button_pressed=TRUE;
-    if (p_button_pressed) 
-	    callback_fullscreen(0, mainview);
+    g_message(_("m button press"));
     return TRUE;
   case GDK_F6:
     callback_fullscreen(0, mainview);
@@ -1547,6 +1553,10 @@ gboolean callback_keyrelease(GtkWidget *widget, GdkEventKey *event,
   case GDK_F7:
   case GDK_F8:
     g_timeout_add(100, (GtkFunction) p_m_button_release, NULL);
+    if (pm_button_for_toggle_fullscreen)
+    	callback_fullscreen(0, mainview);
+    pm_button_for_toggle_fullscreen=FALSE;
+    g_message(_("pm button release"));
     return TRUE;
   }
   if (mainview->directionKeyPress &&
